[Phpmyadmin-git] [SCM] phpMyAdmin branch, master, updated. RELEASE_3_3_1RC1-918-gebd574c
Michal Čihař
nijel at users.sourceforge.net
Tue Mar 30 13:49:31 CEST 2010
The branch, master has been updated
via ebd574c385138fe32449c10bd198d993e51305ea (commit)
via 86cd86fc513aa79eafdf9910b60976ac5750d4eb (commit)
via e20e693316852f0e8efb728b512c766d0ca4be52 (commit)
from 968f1f9d2da9bfcfcd7c8119222f9ebf5eba011b (commit)
- Log -----------------------------------------------------------------
commit ebd574c385138fe32449c10bd198d993e51305ea
Merge: e20e693316852f0e8efb728b512c766d0ca4be52 86cd86fc513aa79eafdf9910b60976ac5750d4eb
Author: Michal Čihař <mcihar at novell.com>
Date: Tue Mar 30 13:49:16 2010 +0200
Merge branch 'QA_3_3'
commit e20e693316852f0e8efb728b512c766d0ca4be52
Author: Michal Čihař <mcihar at novell.com>
Date: Tue Mar 30 13:45:18 2010 +0200
Update generating of bookmarkable url to jQuery.
-----------------------------------------------------------------------
Summary of changes:
index.php | 1 +
js/helper.js | 9 +++++----
libraries/common.inc.php | 1 +
libraries/select_lang.lib.php | 2 +-
4 files changed, 8 insertions(+), 5 deletions(-)
diff --git a/index.php b/index.php
index 34842ec..ca284ff 100644
--- a/index.php
+++ b/index.php
@@ -160,6 +160,7 @@ header('Content-Type: text/html; charset=' . $GLOBALS['charset']);
// ]]>
</script>
<script src="./js/mootools.js" type="text/javascript"></script>
+<script src="./js/jquery/jquery-1.4.2-min.js" type="text/javascript"></script>
<script src="./js/helper.js" type="text/javascript"></script>
<script src="./js/common.js" type="text/javascript"></script>
</head>
diff --git a/libraries/common.inc.php b/libraries/common.inc.php
index 5a4afc4..fd4f3d1 100644
--- a/libraries/common.inc.php
+++ b/libraries/common.inc.php
@@ -546,6 +546,7 @@ $_REQUEST['js_frame'] = PMA_ifSetOr($_REQUEST['js_frame'], '');
*/
$GLOBALS['js_include'] = array();
$GLOBALS['js_include'][] = 'mootools.js';
+$GLOBALS['js_include'][] = 'jquery/jquery-1.4.2-min.js';
$GLOBALS['js_include'][] = 'helper.js';
/**
diff --git a/libraries/select_lang.lib.php b/libraries/select_lang.lib.php
index be1ce37..4c16df7 100644
--- a/libraries/select_lang.lib.php
+++ b/libraries/select_lang.lib.php
@@ -129,7 +129,7 @@ function PMA_langSet(&$lang)
*
* @access private
*/
-function PMA_langDetect(&$str, $envType)
+function PMA_langDetect($str, $envType)
{
if (empty($str)) {
return false;
hooks/post-receive
diff --git a/js/helper.js b/js/helper.js
index b7f6211..0a3fbf1 100644
--- a/js/helper.js
+++ b/js/helper.js
@@ -1,6 +1,6 @@
/* vim: set expandtab sw=4 ts=4 sts=4: */
/**
* Various helper scripts, using mootools.
*
* @version $Id$
*/
@@ -14,7 +14,7 @@ var hash_init_done = 0;
* one.
*/
function setURLHash(hash) {
- if (Browser.Engine.webkit) {
+ if (jQuery.browser.webkit) {
/*
* Setting hash leads to reload in webkit:
* http://www.quirksmode.org/bugreports/archives/2005/05/Safari_13_visual_anomaly_with_windowlocationhref.html
@@ -25,7 +25,8 @@ function setURLHash(hash) {
window.parent.setURLHash(hash);
} else {
/* Do not set if we're not updating frameset */
- if (window.location.pathname.substring(-9, 9) != "index.php") {
+ var path = window.location.pathname;
+ if (path.substring(path.length - 9, path.length) != "index.php") {
return;
}
if (hash_init_done) {
@@ -40,7 +41,7 @@ function setURLHash(hash) {
* Handler for changing url according to the hash part, which is updated
* on each page to allow bookmarks.
*/
-window.addEvent('load', function() {
+jQuery(document).ready(function(){
/* Don't do anything if we're not root Window */
if (window.parent != window && window.parent.setURLHash) {
return;
@@ -1,6 +1,6 @@
/* vim: set expandtab sw=4 ts=4 sts=4: */
/**
- * Various helper scripts, using mootools.
+ * Various helper scripts, using jQuery.
*
* @version $Id$
--
phpMyAdmin
More information about the Git
mailing list